#!/bin/bash

version_of=foam-extend-3.0
compile_hosts="`hostname`:8" # l21:8
umask 0022
if [ $# -lt 1 ]; then
	echo "Usage: $0 <openfoam_install_dir>"
	echo ""
	echo "script will install:"
	echo "          $version_of to <openfoam_install_dir>"
	echo ""
	#echo "script must be executed from the directory where the source .tgz files are located!!!!"
  exit 1
fi

my_inst_dir_base=$1
mkdir -p $my_inst_dir_base

cd ${my_inst_dir_base}
if [ ! -d ${version_of} ]; then
	echo Getting Git repository
	 git clone git://git.code.sf.net/p/openfoam-extend/${version_of}
fi

cd ${version_of}
echo Getting latest Git Version
git checkout 
git checkout -f
my_inst_dir=${my_inst_dir_base}/$version_of
echo changing diretory to ${my_inst_dir}
cd ${my_inst_dir}

#overwrite bash.orig with version from git
cp  etc/bashrc etc/bashrc.orig
#from openfoam version 1.7 
cat etc/bashrc.orig | \
sed -e s?WM_PROJECT_DIR=\$WM_PROJECT_INST_DIR/\$WM_PROJECT-\$WM_FORK-\$WM_PROJECT_VERSION?WM_PROJECT_DIR=\$WM_PROJECT_INST_DIR? | \
sed -e s/WM_MPLIB:=OPENMPI/WM_MPLIB:=INTELMPI/  | \
sed -e s/WM_COMPILER:=Gcc/WM_COMPILER:=Icc/ |\
sed -e s?foamInstall=\$HOME/\$WM_PROJECT?foamInstall=${my_inst_dir}? \
>  etc/bashrc




echo 'INTELMPI)
        export MPI_ROOT=$I_MPI_ROOT
        export FOAM_MPI=intel_mpi.4.1.0.024
        export MPI_ARCH_PATH=$MPI_ROOT
        _foamAddPath    $MPI_ARCH_PATH/bin64
        _foamAddLib     $MPI_ARCH_PATH/lib64
        ;;' > mpi_settings.txt


cd ${my_inst_dir}

cp etc/settings.sh etc/settings.sh.orig
cat etc/settings.sh.orig | \
sed -e '/SYSTEMOPENMPI)/r mpi_settings.txt' -e 'x;$G'  \
> etc/settings.sh

echo 'PFLAGS     = -DMPICH_SKIP_MPICXX
PINC       = -I$(MPI_ARCH_PATH)/include64
PLIBS      = -L$(MPI_ARCH_PATH)/lib64 -lmpi' > wmake/rules/linux64Icc/mplibINTELMPI

rule_file="wmake/rules/linux64Icc/c++Opt"
cp  ${rule_file} ${rule_file}.orig
echo 'c++DBUG     =
c++OPT      = -xHost -O3 -no-prec-div' > ${rule_file}
#c++OPT      = -xSSE2 -O2 -no-prec-div' > ${rule_file}



cd ${my_inst_dir}
source etc/bashrc

export WM_SCHEDULER=wmakeScheduler
export WM_HOSTS="$compile_hosts"
export WM_NCOMPPROCS=$($WM_SCHEDULER -count)
export WM_COLOURS="black blue green cyan red magenta yellow" 

echo executing allwmake, check output in ${my_inst_dir}/allwmake.out
./Allwmake &> allwmake.out 

#decomposePar gives segmentation fault if this is not done:
#chmod 644 /opt/sw/OpenFOAM/OpenFOAM-2.2.2/OpenFOAM-2.2.2/etc/controlDict/controlDict

echo "add the following line to your .bashrc file"
echo "source ${my_inst_dir}/etc/bashrc"

